/* Elvira Bluetooth FTP 
 * Copyright (C) 2007  Alberto Salas Bragado
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include "common_op.h"

/** Identificador de la conexión Bluetooth */
int connection;

int connect_to(device_t *disp) {
	
	connection = bftp_connect(disp);

	if (connection < 0)
		
		return COP_CONN;
	
	return COP_OK;
}

int disconnect() {
	
	if (bftp_disconnect() < 0)
		
		return COP_DISCONN;
	
	return COP_OK;
	
}

int is_connected() {
	
	if (bftp_state() == FTP_CONNECTED)
		return 1;
	else
		return 0;
	
}

int device_search(device_t **list) {
	
	int ndisp;
	device_t *lista;
	
	ndisp = bftp_search(&lista);
	
	if (ndisp < 0) {
		*list = NULL;
		return COP_SCH;
	}
	
	*list = lista;
	return ndisp;
	
}

int writeFavorites(device_t *favorites, int nfavorites) {

	FILE *file_favorites;

	file_favorites = fopen(FILE_FAVORITES, "wb");

	if (file_favorites != NULL) {

		if (fwrite(favorites, sizeof(device_t), nfavorites, file_favorites)
				!= nfavorites)
			return COP_FF_WRITE;

		fclose(file_favorites);

	} else {

		return COP_FF_OPENW;

	}

	return COP_OK;

}

int loadFavorites(device_t **favorites, int *numfavorites) {

	device_t temp;
	FILE *file_favorites;
	
	*favorites = NULL;
	*numfavorites = 0;

	file_favorites = fopen(FILE_FAVORITES, "rb");

	if (file_favorites != NULL) {

		while (fread(&temp, sizeof(device_t), 1, file_favorites)) {
			
			*numfavorites += 1;

			*favorites = (device_t *) realloc(*favorites, sizeof(device_t)
					*(*numfavorites));
			memcpy((*favorites)+(*numfavorites)-1, &temp, sizeof(temp));

		}

		fclose(file_favorites);

	} else {

		return COP_FF_OPENR;

	}

	return COP_OK;

}

int uploadFile(char *local, char *remote) {

	if (bftp_put(local, remote) < 0)

		return COP_UL;

	return COP_OK;
}

int downloadFile(char *local, char *remote) {

	if (bftp_get(local, remote) < 0)

		return COP_DL;

	return COP_OK;
}

int deleteLocalFile(char *file) {

	if (unlink(file) < 0)

		return COP_DEL;

	return COP_OK;

}

int deleteRemoteFile(char *file) {

	if (bftp_del(file) < 0)

		return COP_DEL;

	return COP_OK;

}

int mkdirLocal(char *name) {

	if (mkdir(name, 0755) < 0)

		return COP_MD;

	return COP_OK;

}

int mkdirRemote(char *name) {

	if (bftp_mkdir(name) < 0)

		return COP_MD;

	return COP_OK;

}

//comprueba si el directorio contiene ficheros
int deleteLocalDir(char *name) {
	
	if (rmdir(name) < 0)
		
		return COP_RD;
	
	return COP_OK;
	
}

//comprueba si el directorio contiene ficheros
int deleteRemoteDir(char *name) {
	
	int nficheros;
	file_t *lista;
	
	nficheros = bftp_list(name, &lista);
	free(lista);
	
	if (nficheros == 0)
		
		return deleteRemoteFile(name);
	
	return COP_RD;
	
}

int listRemoteDir(char *name, file_t **list) {
	
	int nficheros;
	file_t *lista;
	
	nficheros = bftp_list(name, &lista);
	
	if (nficheros < 0) {
		
		*list = NULL;
		return COP_LIST;
	
	}
	
	*list = lista;
	return (nficheros);
	
}

int listLocalDir(char *name, file_t **list) {
	
	int nficheros;
	file_t *lista;
	
	nficheros = localfs_list(name, &lista);
	
	if (nficheros < 0) {
		
		*list = NULL;
		return COP_LIST;
		
	}
	
	*list = lista;
	return (nficheros);
}

int permsLocalRead(char *name) {
	
	if (localfs_rperm(name) < 0)
		
		return -1;
	
	return 0;
	
}

int permsLocalWrite(char *name) {
	
	if (localfs_wperm(name) < 0)
		
		return -1;
	
	return 0;
	
}

int existLocal(char *name) {
	
	if (localfs_exist(name) < 0)
		
		return -1;
	
	return 0;
	
}

int existRemote(char *name) {
	
	if (bftp_file_exist(name) < 0)
		
		return -1;
	
	return 0;
	
}
